@@ -1,6 +1,6 @@
 package Git::Raw::Config;
 {
-  $Git::Raw::Config::VERSION = '0.23';
+  $Git::Raw::Config::VERSION = '0.24';
 }
 
 use strict;
@@ -14,7 +14,7 @@ Git::Raw::Config - Git config class
 
 =head1 VERSION
 
-version 0.23
+version 0.24
 
 =head1 DESCRIPTION
 
@@ -37,19 +37,19 @@ Add C<$path> to the config object with priority level C<$level>.
 
 Retrieve the value of the C<$name> configuration field of type boolean. If
 C<$value> is passed, the value of the configration will be updated and
-returned.
+returned. If not C<$name> configuration is found, C<undef> is returned.
 
 =head2 int( $name [, $value ] )
 
 Retrieve the value of the C<$name> configuration field of type integer. If
 C<$value> is passed, the value of the configration will be updated and
-returned.
+returned. If not C<$name> configuration is found, C<undef> is returned.
 
 =head2 str( $name [, $value ] )
 
 Retrieve the value of the C<$name> configuration field of type string. If
 C<$value> is passed, the value of the configration will be updated and
-returned.
+returned. If not C<$name> configuration is found, C<undef> is returned.
 
 =head2 foreach( $callback )
 
