@@ -564,6 +564,14 @@ GIT_EXTERN(int) git_index_reuc_add(git_index *index, const char *path,
  */
 GIT_EXTERN(int) git_index_reuc_remove(git_index *index, size_t n);
 
+/**
+ * Remove all resolve undo entries from the index
+ *
+ * @param index an existing index object
+ * @return 0 or an error code
+ */
+GIT_EXTERN(void) git_index_reuc_clear(git_index *index);
+
 /**@}*/
 
 /** @} */
