@@ -1,6 +1,7 @@
 #include "clar_libgit2.h"
 #include "index.h"
 #include "git2/repository.h"
+#include "../reset/reset_helpers.h"
 
 static git_repository *repo;
 static git_index *repo_index;
@@ -31,6 +32,56 @@ void test_index_reuc__cleanup(void)
 	cl_git_sandbox_cleanup();
 }
 
+void test_index_reuc__add(void)
+{
+	git_oid ancestor_oid, our_oid, their_oid;
+	const git_index_reuc_entry *reuc;
+
+	git_oid_fromstr(&ancestor_oid, ONE_ANCESTOR_OID);
+	git_oid_fromstr(&our_oid, ONE_OUR_OID);
+	git_oid_fromstr(&their_oid, ONE_THEIR_OID);
+
+	cl_git_pass(git_index_reuc_add(repo_index, "newfile.txt",
+		0100644, &ancestor_oid,
+		0100644, &our_oid,
+		0100644, &their_oid));
+
+	cl_assert(reuc = git_index_reuc_get_bypath(repo_index, "newfile.txt"));
+
+	cl_assert_equal_s("newfile.txt", reuc->path);
+	cl_assert(reuc->mode[0] == 0100644);
+	cl_assert(reuc->mode[1] == 0100644);
+	cl_assert(reuc->mode[2] == 0100644);
+	cl_assert(git_oid_cmp(&reuc->oid[0], &ancestor_oid) == 0);
+	cl_assert(git_oid_cmp(&reuc->oid[1], &our_oid) == 0);
+	cl_assert(git_oid_cmp(&reuc->oid[2], &their_oid) == 0);
+}
+
+void test_index_reuc__add_no_ancestor(void)
+{
+	git_oid ancestor_oid, our_oid, their_oid;
+	const git_index_reuc_entry *reuc;
+
+	memset(&ancestor_oid, 0x0, sizeof(git_oid));
+	git_oid_fromstr(&our_oid, ONE_OUR_OID);
+	git_oid_fromstr(&their_oid, ONE_THEIR_OID);
+
+	cl_git_pass(git_index_reuc_add(repo_index, "newfile.txt",
+		0, NULL,
+		0100644, &our_oid,
+		0100644, &their_oid));
+
+	cl_assert(reuc = git_index_reuc_get_bypath(repo_index, "newfile.txt"));
+
+	cl_assert_equal_s("newfile.txt", reuc->path);
+	cl_assert(reuc->mode[0] == 0);
+	cl_assert(reuc->mode[1] == 0100644);
+	cl_assert(reuc->mode[2] == 0100644);
+	cl_assert(git_oid_cmp(&reuc->oid[0], &ancestor_oid) == 0);
+	cl_assert(git_oid_cmp(&reuc->oid[1], &our_oid) == 0);
+	cl_assert(git_oid_cmp(&reuc->oid[2], &their_oid) == 0);
+}
+
 void test_index_reuc__read_bypath(void)
 {
 	const git_index_reuc_entry *reuc;
@@ -40,7 +91,7 @@ void test_index_reuc__read_bypath(void)
 
 	cl_assert(reuc = git_index_reuc_get_bypath(repo_index, "two.txt"));
 
-	cl_assert(strcmp(reuc->path, "two.txt") == 0);
+	cl_assert_equal_s("two.txt", reuc->path);
 	cl_assert(reuc->mode[0] == 0100644);
 	cl_assert(reuc->mode[1] == 0100644);
 	cl_assert(reuc->mode[2] == 0100644);
@@ -53,7 +104,7 @@ void test_index_reuc__read_bypath(void)
 
 	cl_assert(reuc = git_index_reuc_get_bypath(repo_index, "one.txt"));
 
-	cl_assert(strcmp(reuc->path, "one.txt") == 0);
+	cl_assert_equal_s("one.txt", reuc->path);
 	cl_assert(reuc->mode[0] == 0100644);
 	cl_assert(reuc->mode[1] == 0100644);
 	cl_assert(reuc->mode[2] == 0100644);
@@ -85,7 +136,7 @@ void test_index_reuc__ignore_case(void)
 
 	cl_assert(reuc = git_index_reuc_get_bypath(repo_index, "TWO.txt"));
 
-	cl_assert(strcmp(reuc->path, "two.txt") == 0);
+	cl_assert_equal_s("two.txt", reuc->path);
 	cl_assert(reuc->mode[0] == 0100644);
 	cl_assert(reuc->mode[1] == 0100644);
 	cl_assert(reuc->mode[2] == 0100644);
@@ -106,7 +157,7 @@ void test_index_reuc__read_byindex(void)
 
 	cl_assert(reuc = git_index_reuc_get_byindex(repo_index, 0));
 
-	cl_assert(strcmp(reuc->path, "one.txt") == 0);
+	cl_assert_equal_s("one.txt", reuc->path);
 	cl_assert(reuc->mode[0] == 0100644);
 	cl_assert(reuc->mode[1] == 0100644);
 	cl_assert(reuc->mode[2] == 0100644);
@@ -119,7 +170,7 @@ void test_index_reuc__read_byindex(void)
 
 	cl_assert(reuc = git_index_reuc_get_byindex(repo_index, 1));
 
-	cl_assert(strcmp(reuc->path, "two.txt") == 0);
+	cl_assert_equal_s("two.txt", reuc->path);
 	cl_assert(reuc->mode[0] == 0100644);
 	cl_assert(reuc->mode[1] == 0100644);
 	cl_assert(reuc->mode[2] == 0100644);
@@ -162,7 +213,7 @@ void test_index_reuc__updates_existing(void)
 
 	cl_assert(reuc = git_index_reuc_get_byindex(repo_index, 0));
 
-	cl_assert(strcmp(reuc->path, "TWO.txt") == 0);
+	cl_assert_equal_s("TWO.txt", reuc->path);
 	git_oid_fromstr(&oid, TWO_OUR_OID);
 	cl_assert(git_oid_cmp(&reuc->oid[0], &oid) == 0);
 	git_oid_fromstr(&oid, TWO_THEIR_OID);
@@ -185,7 +236,7 @@ void test_index_reuc__remove(void)
 
 	cl_assert(reuc = git_index_reuc_get_byindex(repo_index, 0));
 
-	cl_assert(strcmp(reuc->path, "two.txt") == 0);
+	cl_assert_equal_s("two.txt", reuc->path);
 	cl_assert(reuc->mode[0] == 0100644);
 	cl_assert(reuc->mode[1] == 0100644);
 	cl_assert(reuc->mode[2] == 0100644);
@@ -230,9 +281,93 @@ void test_index_reuc__write(void)
 
 	/* ensure sort order was round-tripped correct */
 	cl_assert(reuc = git_index_reuc_get_byindex(repo_index, 0));
-	cl_assert(strcmp(reuc->path, "one.txt") == 0);
+	cl_assert_equal_s("one.txt", reuc->path);
 	
 	cl_assert(reuc = git_index_reuc_get_byindex(repo_index, 1));
-	cl_assert(strcmp(reuc->path, "two.txt") == 0);
+	cl_assert_equal_s("two.txt", reuc->path);
 }
 
+static int reuc_entry_exists(void)
+{
+	return (git_index_reuc_get_bypath(repo_index, "newfile.txt") != NULL);
+}
+
+void test_index_reuc__cleaned_on_reset_hard(void)
+{
+	git_object *target;
+	
+	retrieve_target_from_oid(&target, repo, "3a34580a35add43a4cf361e8e9a30060a905c876");
+	
+	test_index_reuc__add();
+	cl_git_pass(git_reset(repo, target, GIT_RESET_HARD));
+	cl_assert(reuc_entry_exists() == false);
+	
+	git_object_free(target);
+}
+
+void test_index_reuc__cleaned_on_reset_mixed(void)
+{
+	git_object *target;
+	
+	retrieve_target_from_oid(&target, repo, "3a34580a35add43a4cf361e8e9a30060a905c876");
+
+	test_index_reuc__add();	
+	cl_git_pass(git_reset(repo, target, GIT_RESET_MIXED));
+	cl_assert(reuc_entry_exists() == false);
+	
+	git_object_free(target);
+}
+
+void test_index_reuc__retained_on_reset_soft(void)
+{
+	git_object *target;
+	
+	retrieve_target_from_oid(&target, repo, "3a34580a35add43a4cf361e8e9a30060a905c876");
+	
+	git_reset(repo, target, GIT_RESET_HARD);
+
+	test_index_reuc__add();
+	cl_git_pass(git_reset(repo, target, GIT_RESET_SOFT));
+	cl_assert(reuc_entry_exists() == true);
+	
+	git_object_free(target);
+}
+
+void test_index_reuc__cleaned_on_checkout_tree(void)
+{
+	git_oid oid;
+	git_object *obj;
+	git_checkout_opts opts = GIT_CHECKOUT_OPTS_INIT;
+	
+	opts.checkout_strategy = GIT_CHECKOUT_SAFE | GIT_CHECKOUT_UPDATE_ONLY;
+
+	test_index_reuc__add();
+	git_reference_name_to_id(&oid, repo, "refs/heads/master");
+	git_object_lookup(&obj, repo, &oid, GIT_OBJ_ANY);
+	git_checkout_tree(repo, obj, &opts);
+	cl_assert(reuc_entry_exists() == false);
+	
+	git_object_free(obj);
+}
+
+void test_index_reuc__cleaned_on_checkout_head(void)
+{
+	git_checkout_opts opts = GIT_CHECKOUT_OPTS_INIT;
+	
+	opts.checkout_strategy = GIT_CHECKOUT_SAFE | GIT_CHECKOUT_UPDATE_ONLY;
+	
+	test_index_reuc__add();
+	git_checkout_head(repo, &opts);
+	cl_assert(reuc_entry_exists() == false);
+}
+
+void test_index_reuc__retained_on_checkout_index(void)
+{
+	git_checkout_opts opts = GIT_CHECKOUT_OPTS_INIT;
+	
+	opts.checkout_strategy = GIT_CHECKOUT_SAFE | GIT_CHECKOUT_UPDATE_ONLY;
+	
+	test_index_reuc__add();
+	git_checkout_index(repo, repo_index, &opts);
+	cl_assert(reuc_entry_exists() == true);
+}
